@@ -3,6 +3,8 @@
 import os
 import unittest
 
+import apt_pkg
+apt_pkg.config.set("Dir", "./aptroot")
 import apt
 
 import unattended_upgrade
@@ -16,7 +18,7 @@ class MockOptions(object):
     download_only = False
     dry_run = True
     apt_debug = False
-    minimal_upgrade_steps = False
+    minimal_upgrade_steps = True
 
 
 class TestUntrusted(unittest.TestCase):
@@ -36,11 +38,21 @@ class TestUntrusted(unittest.TestCase):
         os.remove(self.log)
 
     def test_untrusted_check_without_conffile_check(self):
+        apt_conf = os.path.join(self.rootdir, "etc", "apt", "apt.conf")
+        with open(apt_conf, "w") as fp:
+            fp.write("""Unattended-Upgrade::Allowed-Origins {
+"Ubuntu:lucid-security";
+};
+Unattended-Upgrade::OnlyOnACPower "false";
+Unattended-Upgrade::Skip-Updates-On-Metered-Connections "false";
+""")
         # ensure there is no conffile_prompt check
         apt.apt_pkg.config.set("DPkg::Options::", "--force-confold")
 
         # run it
         options = MockOptions()
+        unattended_upgrade.DISTRO_DESC = "Ubuntu 10.04"
+        unattended_upgrade.LOCK_FILE = "./u-u.lock"
         unattended_upgrade.main(options, rootdir=self.rootdir)
         # read the log to see what happend
         with open(self.log) as f:
@@ -48,7 +60,7 @@ class TestUntrusted(unittest.TestCase):
             haystack = f.read()
             self.assertTrue(needle in haystack,
                             "Can not find '%s' in '%s'" % (needle, haystack))
-            self.assertTrue("pkg 'test-package' is untrusted" in haystack)
+            self.assertTrue("pkg test-package is untrusted" in haystack)
 
 
 if __name__ == "__main__":
